@@ -1,8 +1,4 @@
 prepResult <- function(zScale, output, regulatoryNetwork, geneCoreg, tfCoopNetwork, edgelist, motif){
-  resList <- list()
-  numGenes = dim(geneCoreg)[1]
-  numTFs   = dim(tfCoopNetwork)[1]
-  numEdges = sum(regulatoryNetwork!=0)
   # if (!zScale){
   #   regulatoryNetwork <- stats::pnorm(regulatoryNetwork)
   #   geneCoreg         <- stats::pnorm(geneCoreg)
@@ -30,5 +26,9 @@ prepResult <- function(zScale, output, regulatoryNetwork, geneCoreg, tfCoopNetwo
   #   # }
   #   resList$coopNet <- tfCoopNetwork
   # }
+  resList <- list()
+  numGenes = dim(geneCoreg)[1]
+  numTFs   = dim(tfCoopNetwork)[1]
+  numEdges = sum(apply(regulatoryNetwork,1,function(X){X!=0}))
   list(regNet=regulatoryNetwork, coregNet=geneCoreg, coopNet=tfCoopNetwork, numGenes=numGenes, numTFs=numTFs, numEdges=numEdges)
 }
